@@ -12,7 +12,7 @@ use Yahoo::Marketing::ReportInfo;
 sub test_can_create_report_info_and_set_all_fields : Test(5) {
 
     my $report_info = Yahoo::Marketing::ReportInfo->new
-                                                  ->createDate( 'create date' )
+                                                  ->createDate( '2008-01-06T17:51:55' )
                                                   ->reportID( 'report id' )
                                                   ->reportName( 'report name' )
                                                   ->status( 'status' )
@@ -20,7 +20,7 @@ sub test_can_create_report_info_and_set_all_fields : Test(5) {
 
     ok( $report_info );
 
-    is( $report_info->createDate, 'create date', 'can get create date' );
+    is( $report_info->createDate, '2008-01-06T17:51:55', 'can get 2008-01-06T17:51:55' );
     is( $report_info->reportID, 'report id', 'can get report id' );
     is( $report_info->reportName, 'report name', 'can get report name' );
     is( $report_info->status, 'status', 'can get status' );
